From 6207b66d3d48ad1cd40050538e4c2dccef7eac4c Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Benedek=20L=C3=A1szl=C3=B3?= <laszlo.benedek@hu.digi.tv>
Date: Thu, 22 Jul 2010 16:07:24 +0200
Subject: [PATCH 2/2] Role support in database backups

Add the possibility to specify a rolename for pg_dump
---
 pgadmin/frm/frmBackup.cpp |   12 ++
 pgadmin/ui/frmBackup.xrc  |   12 ++
 pgadmin/ui/xrcDialogs.cpp |  400 ++++++++++++++++++++++++---------------------
 3 files changed, 237 insertions(+), 187 deletions(-)

diff --git a/pgadmin/frm/frmBackup.cpp b/pgadmin/frm/frmBackup.cpp
index 1ff267e..abec080 100644
--- a/pgadmin/frm/frmBackup.cpp
+++ b/pgadmin/frm/frmBackup.cpp
@@ -33,6 +33,7 @@
 #define txtCompressRatio        CTRL_TEXT("txtCompressRatio")
 #define cbEncoding              CTRL_COMBOBOX("cbEncoding")
 #define rbxFormat               CTRL_RADIOBOX("rbxFormat")
+#define txtRolename             CTRL_TEXT("txtRolename")
 #define chkBlobs                CTRL_CHECKBOX("chkBlobs")
 #define chkOid                  CTRL_CHECKBOX("chkOid")
 #define chkInsert               CTRL_CHECKBOX("chkInsert")
@@ -55,6 +56,7 @@ BEGIN_EVENT_TABLE(frmBackup, ExternProcessDialog)
     EVT_TEXT(XRCID("txtFilename"),          frmBackup::OnChange)
     EVT_BUTTON(XRCID("btnFilename"),        frmBackup::OnSelectFilename)
     EVT_BUTTON(wxID_OK,                     frmBackup::OnOK)
+    EVT_TEXT(XRCID("txtRolename"),          frmBackup::OnChange)
     EVT_RADIOBOX(XRCID("rbxFormat"),        frmBackup::OnChangePlain)
     EVT_CHECKBOX(XRCID("chkOnlyData"),      frmBackup::OnChangePlain)
     EVT_CHECKBOX(XRCID("chkOnlySchema"),    frmBackup::OnChangePlain)
@@ -89,6 +91,12 @@ frmBackup::frmBackup(frmMain *form, pgObject *obj) : ExternProcessDialog(form)
     settings->Read(wxT("frmBackup/LastFile"), &val, wxEmptyString);
     txtFilename->SetValue(val);
 
+    if (pgAppMinimumVersion(backupExecutable + wxT(" --version"), 8, 4)) {
+        txtRolename->SetValue(object->GetServer()->GetRolename());
+    } else {
+        txtRolename->Enable(false);
+    }
+
     if (!object->GetDatabase()->GetServer()->GetPasswordIsStored())
         environment.Add(wxT("PGPASSWORD=") + object->GetServer()->GetPassword());
 
@@ -300,6 +308,10 @@ wxString frmBackup::getCmdPart1()
     cmd +=  wxT(" --port ") + NumToStr((long)server->GetPort())
          +  wxT(" --username ") + commandLineCleanOption(qtIdent(server->GetUsername()));
 
+    if (!txtRolename->GetValue().IsEmpty()) {
+        cmd +=  wxT(" --role ") + commandLineCleanOption(qtIdent(txtRolename->GetValue()));
+    }
+
     if (object->GetConnection()->GetIsGreenplum())
         cmd += wxT(" --gp-syntax ");
     return cmd;
diff --git a/pgadmin/ui/frmBackup.xrc b/pgadmin/ui/frmBackup.xrc
index 3f91aa9..2dd40f8 100644
--- a/pgadmin/ui/frmBackup.xrc
+++ b/pgadmin/ui/frmBackup.xrc
@@ -103,6 +103,18 @@
                   <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
                   <border>4</border>
                 </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stRolename">
+                    <label>Rolename</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxTextCtrl" name="txtRolename"/>
+                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
               </object>
             </object>
           </object>
diff --git a/pgadmin/ui/xrcDialogs.cpp b/pgadmin/ui/xrcDialogs.cpp
index b910c6c..17211ce 100644
--- a/pgadmin/ui/xrcDialogs.cpp
+++ b/pgadmin/ui/xrcDialogs.cpp
@@ -24715,7 +24715,7 @@ static unsigned char xml_res_file_57[] = {
 32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,101,99,
 116,62,10,60,47,114,101,115,111,117,114,99,101,62,10};
 
-static size_t xml_res_size_58 = 15668;
+static size_t xml_res_size_58 = 16245;
 static unsigned char xml_res_file_58[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -24932,66 +24932,151 @@ static unsigned char xml_res_file_58[] = {
 32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
 114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
 47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,
-99,116,32,99,108,97,115,115,61,34,110,111,116,101,98,111,111,107,112,97,
-103,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,
-62,68,117,109,112,32,79,112,116,105,111,110,115,32,35,49,60,47,108,97,98,
-101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,119,120,80,97,110,101,108,34,32,110,97,109,
-101,61,34,112,110,108,68,117,109,112,79,112,116,105,111,110,115,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,
-114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,
-108,115,62,49,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,114,111,119,115,62,51,60,47,114,111,119,115,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,
-60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,104,103,97,112,62,53,60,47,104,103,97,112,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,
-115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,66,111,120,83,105,
-122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,108,97,98,101,108,62,84,121,112,101,32,79,102,32,79,98,106,
-101,99,116,115,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,49,60,47,99,111,108,
-115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-114,111,119,115,62,51,60,47,114,111,119,115,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,60,47,118,
-103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,
-101,99,111,108,115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,
-115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-111,114,105,101,110,116,62,119,120,86,69,82,84,73,67,65,76,60,47,111,114,
-105,101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,
-101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
-61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,
-104,107,79,110,108,121,68,97,116,97,34,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,79,
-110,108,121,32,100,97,116,97,60,47,108,97,98,101,108,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,
-120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
-108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
+82,111,108,101,110,97,109,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,82,111,108,101,110,97,
+109,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,
+73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,
+79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,
+32,110,97,109,101,61,34,116,120,116,82,111,108,101,110,97,109,101,34,47,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,110,111,116,101,98,
+111,111,107,112,97,103,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+60,108,97,98,101,108,62,68,117,109,112,32,79,112,116,105,111,110,115,32,
+35,49,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,80,97,110,101,
+108,34,32,110,97,109,101,61,34,112,110,108,68,117,109,112,79,112,116,105,
+111,110,115,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,
+105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,99,111,108,115,62,49,60,47,99,111,108,115,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,114,111,119,115,62,51,60,47,114,
+111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,
+103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,
+108,101,99,111,108,115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,
+108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,
+99,66,111,120,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,84,121,112,101,32,
+79,102,32,79,98,106,101,99,116,115,60,47,108,97,98,101,108,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,
+62,49,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,114,111,119,115,62,51,60,47,114,111,119,115,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,
+97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,
+114,111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,111,119,97,
+98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,111,114,105,101,110,116,62,119,120,86,69,82,84,
+73,67,65,76,60,47,111,114,105,101,110,116,62,10,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,
-101,61,34,99,104,107,79,110,108,121,83,99,104,101,109,97,34,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,
-97,98,101,108,62,79,110,108,121,32,115,99,104,101,109,97,60,47,108,97,98,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,
+120,34,32,110,97,109,101,61,34,99,104,107,79,110,108,121,68,97,116,97,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,108,97,98,101,108,62,79,110,108,121,32,100,97,116,97,60,47,108,
+97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,
+69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
+120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
+60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,66,
+111,120,34,32,110,97,109,101,61,34,99,104,107,79,110,108,121,83,99,104,
+101,109,97,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,108,97,98,101,108,62,79,110,108,121,32,115,99,104,
+101,109,97,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,
+101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,66,108,111,
+98,115,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,108,97,98,101,108,62,66,108,111,98,115,60,47,108,97,98,
+101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,99,104,101,99,107,101,100,62,49,60,47,99,104,101,99,107,
+101,100,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
+80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,
+84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,
+82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,
+47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,
+82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
+60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,
+115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,119,120,83,116,97,116,105,99,66,111,120,83,105,122,101,114,34,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
+98,101,108,62,68,111,110,39,116,32,115,97,118,101,60,47,108,97,98,101,108,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,
+111,108,115,62,49,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,114,111,119,115,62,51,60,47,114,111,
+119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,118,103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,
+104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,
+114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,114,105,101,110,116,62,119,120,
+86,69,82,84,73,67,65,76,60,47,111,114,105,101,110,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,
+66,111,120,34,32,110,97,109,101,61,34,99,104,107,78,111,79,119,110,101,
+114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,108,97,98,101,108,62,79,119,110,101,114,60,47,108,97,98,
 101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
@@ -25005,127 +25090,26 @@ static unsigned char xml_res_file_58[] = {
 108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
 101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,
-120,34,32,110,97,109,101,61,34,99,104,107,66,108,111,98,115,34,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-108,97,98,101,108,62,66,108,111,98,115,60,47,108,97,98,101,108,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-99,104,101,99,107,101,100,62,49,60,47,99,104,101,99,107,101,100,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,
-120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,
-119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,
-47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,
-65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,
-73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,
-73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
-105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,
-97,116,105,99,66,111,120,83,105,122,101,114,34,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,68,111,
-110,39,116,32,115,97,118,101,60,47,108,97,98,101,108,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,49,
-60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,114,111,119,115,62,51,60,47,114,111,119,115,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,
-112,62,53,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,
-111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,111,119,97,98,
-108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,111,114,105,101,110,116,62,119,120,86,69,82,84,73,
-67,65,76,60,47,111,114,105,101,110,116,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
-115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,
-99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,120,
-34,32,110,97,109,101,61,34,99,104,107,78,111,79,119,110,101,114,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,108,97,98,101,108,62,79,119,110,101,114,60,47,108,97,98,101,108,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
-119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,
-124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
-60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,
-109,101,61,34,99,104,107,78,111,80,114,105,118,105,108,101,103,101,115,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,108,97,98,101,108,62,80,114,105,118,105,108,101,103,101,60,
-47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,
-120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,
-86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
-119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
-62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,
-107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,78,111,84,97,98,108,
-101,115,112,97,99,101,115,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,84,97,98,108,
-101,115,112,97,99,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,
-78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,
-124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,
-120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
-108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,
+120,34,32,110,97,109,101,61,34,99,104,107,78,111,80,114,105,118,105,108,
+101,103,101,115,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,80,114,105,118,105,108,
+101,103,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,66,111,
-120,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,108,97,98,101,108,62,81,117,101,114,105,101,115,
-60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,99,111,108,115,62,49,60,47,99,111,108,115,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,114,111,119,
-115,62,52,60,47,114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,97,112,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,
-103,97,112,62,53,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,
-108,115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,114,
-105,101,110,116,62,119,120,86,69,82,84,73,67,65,76,60,47,111,114,105,101,
-110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,
-107,67,114,101,97,116,101,68,98,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,73,110,
-99,108,117,100,101,32,67,82,69,65,84,69,32,68,65,84,65,66,65,83,69,32,115,
-116,97,116,101,109,101,110,116,60,47,108,97,98,101,108,62,10,32,32,32,32,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,
+101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,78,111,84,97,
+98,108,101,115,112,97,99,101,115,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,84,97,
+98,108,101,115,112,97,99,101,60,47,108,97,98,101,108,62,10,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
 101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
@@ -25135,13 +25119,38 @@ static unsigned char xml_res_file_58[] = {
 32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
 111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,
-101,61,34,99,104,107,68,114,111,112,68,98,34,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,
-62,73,110,99,108,117,100,101,32,68,82,79,80,32,68,65,84,65,66,65,83,69,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,
+124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,
+76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
+84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,
+101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,
+105,99,66,111,120,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,81,117,101,114,
+105,101,115,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,49,60,47,99,111,108,
+115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+114,111,119,115,62,52,60,47,114,111,119,115,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,60,47,118,
+103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,
+101,99,111,108,115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,
+115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+111,114,105,101,110,116,62,119,120,86,69,82,84,73,67,65,76,60,47,111,114,
+105,101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,
+101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,
+104,107,67,114,101,97,116,101,68,98,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,73,
+110,99,108,117,100,101,32,67,82,69,65,84,69,32,68,65,84,65,66,65,83,69,
 32,115,116,97,116,101,109,101,110,116,60,47,108,97,98,101,108,62,10,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
 98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
@@ -25156,6 +25165,23 @@ static unsigned char xml_res_file_58[] = {
 34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
 108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,
+109,101,61,34,99,104,107,68,114,111,112,68,98,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,73,110,99,108,117,100,101,32,68,82,79,80,32,68,65,84,65,66,65,83,
+69,32,115,116,97,116,101,109,101,110,116,60,47,108,97,98,101,108,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
+119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
+101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,
 109,101,61,34,99,104,107,67,111,108,117,109,110,73,110,115,101,114,116,
 115,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,108,97,98,101,108,62,85,115,101,32,67,111,108,117,109,110,
-- 
1.7.1

